@@ -6,7 +6,7 @@
  *                                                                         *
  *   copyright (C) 2002                                                    *
  *   Luis De la Parra <luis@delaparra.org>                                 *
- *   copyright (C) 2003-2014                                               *
+ *   copyright (C) 2003-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -26,12 +26,17 @@
 #include "umldoc.h"
 
 //kde includes
-#include <knuminput.h>
+#if QT_VERSION < 0x050000
 #include <kfiledialog.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KIntSpinBox>
+#endif
+#include <KLocalizedString>
+#include <KMessageBox>
 
 //qt includes
+#if QT_VERSION >= 0x050000
+#include <QFileDialog>
+#endif
 #include <QListWidget>
 
 /**
@@ -111,6 +116,8 @@ void CodeGenStatusPage::generateCode()
     if (codeGenerator) {
         connect(codeGenerator, SIGNAL(codeGenerated(UMLClassifier*,bool)),
                 this, SLOT(classGenerated(UMLClassifier*,bool)));
+        connect(codeGenerator, SIGNAL(codeGenerated(UMLClassifier*, CodeGenerator::GenerationState)),
+                this, SLOT(classGenerated(UMLClassifier*, CodeGenerator::GenerationState)));
         connect(codeGenerator, SIGNAL(showGeneratedFile(QString)),
                 this, SLOT(showFileGenerated(QString)));
 
@@ -119,7 +126,7 @@ void CodeGenStatusPage::generateCode()
         for (int row = 0; row < ui_tableWidgetStatus->rowCount(); ++row) {
             QTableWidgetItem* item = ui_tableWidgetStatus->item(row, 0);
             UMLClassifier *concept = doc->findUMLClassifier(item->text());
-            if (concept == NULL) {
+            if (concept == 0) {
                 uError() << "Could not find classifier " << item->text()
                          << " - not included in generated code.";
                 continue;
@@ -150,7 +157,17 @@ bool CodeGenStatusPage::isComplete() const
  */
 void CodeGenStatusPage::classGenerated(UMLClassifier* concept, bool generated)
 {
-    QList<QTableWidgetItem*> items = ui_tableWidgetStatus->findItems(concept->fullyQualifiedName(), Qt::MatchFixedString);
+    classGenerated(concept, generated ? CodeGenerator::Generated : CodeGenerator::Failed);
+}
+
+/**
+ * Updates the status of the code generation in the status table.
+ * @param concept     the class for which the code was generated
+ * @param state   the state of the generation
+ */
+void CodeGenStatusPage::classGenerated(UMLClassifier* classifier, CodeGenerator::GenerationState state)
+{
+    QList<QTableWidgetItem*> items = ui_tableWidgetStatus->findItems(classifier->fullyQualifiedName(), Qt::MatchFixedString);
     if (items.count() > 0) {
         QTableWidgetItem* item = items.at(0);
         if (!item) {
@@ -160,15 +177,20 @@ void CodeGenStatusPage::classGenerated(UMLClassifier* concept, bool generated)
             int row = ui_tableWidgetStatus->row(item);
             QTableWidgetItem* status = ui_tableWidgetStatus->item(row, 1);
             LedStatus* led = (LedStatus*)ui_tableWidgetStatus->cellWidget(row, 2);
-            if (generated) {
+            if (state == CodeGenerator::Generated) {
                 status->setText(i18n("Code Generated"));
                 led->setOn(true);
             }
-            else {
+            else if (state == CodeGenerator::Failed) {
                 status->setText(i18n("Not Generated"));
                 led->setColor(Qt::red);
                 led->setOn(true);
             }
+            else if (state == CodeGenerator::Skipped) {
+                status->setText(i18n("Skipped"));
+                led->setColor(Qt::gray);
+                led->setOn(true);
+            }
         }
     }
 }
@@ -211,7 +233,11 @@ void CodeGenStatusPage::loggerClear()
 void CodeGenStatusPage::loggerExport()
 {
     const QString caption = i18n("Umbrello Code Generation - Logger Export");
+#if QT_VERSION >= 0x050000
+    QString fileName = QFileDialog::getSaveFileName(this, caption, QLatin1String("UmbrelloCodeGenerationLogger.html"));
+#else
     QString fileName = KFileDialog::getSaveFileName(KUrl(), QString(), 0, caption);
+#endif
     if (!fileName.isEmpty()) {
         QFile file(fileName);
         if (file.open(QIODevice::WriteOnly | QIODevice::Text)) {
@@ -225,4 +251,3 @@ void CodeGenStatusPage::loggerExport()
     }
 }
 
-#include "codegenstatuspage.moc"
