@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2015                                                    *
+ *   copyright (C) 2015-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -20,7 +20,7 @@ class StereotypesWindow : public QDockWidget
 {
     Q_OBJECT
 public:
-    explicit StereotypesWindow(QWidget *parent = 0);
+    explicit StereotypesWindow(const QString &title, QWidget *parent = 0);
     ~StereotypesWindow();
 
 signals:
@@ -33,6 +33,7 @@ protected slots:
 
 protected:
     QTableView *m_stereotypesTree;
+    void contextMenuEvent(QContextMenuEvent *event);
 };
 
 #endif // STEREOTYPESWINDOW_H
