@@ -35,7 +35,7 @@ public:
 
     virtual UMLObject* clone() const;
 
-    void saveToXMI1(QDomDocument & qDoc, QDomElement & qElement);
+    void saveToXMI1(QXmlStreamWriter& writer);
 
 protected:
 
