@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -32,6 +32,7 @@
 #include <QKeyEvent>
 #include <QMouseEvent>
 #include <QPixmap>
+#include <QXmlStreamWriter>
 
 // forward declarations
 class ClassOptionsPage;
@@ -148,10 +149,11 @@ public:
     Settings::OptionState& optionState();
     void setOptionState(const Settings::OptionState& options);
 
-    AssociationWidgetList& associationList();
-    const UMLWidgetList& widgetList() const;
-    void addWidget(UMLWidget* widget);
-    MessageWidgetList& messageList();
+    const AssociationWidgetList associationList() const;
+    const MessageWidgetList messageList() const;
+    const UMLWidgetList widgetList() const;
+    void addWidgetCmd(UMLWidget* widget);
+    void addWidgetCmd(AssociationWidget *widget);
 
     bool isOpen() const;
     void setIsOpen(bool isOpen);
@@ -175,12 +177,15 @@ public:
                                        UMLWidget *pWidgetB, const QString& roleNameB);
 
     void removeWidget(UMLWidget *o);
+    void removeWidget(AssociationWidget *w);
     void removeWidgetCmd(UMLWidget *o);
 private:
     void removeOwnedWidgets(UMLWidget* o);
 public:
 
     UMLWidgetList selectedWidgets() const;
+    AssociationWidgetList selectedAssociationWidgets() const;
+    UMLWidgetList selectedMessageWidgets() const;
     void clearSelected();
 
     void moveSelectedBy(qreal dX, qreal dY);
@@ -203,12 +208,14 @@ public:
     void selectAll();
 
     UMLWidget* widgetOnDiagram(Uml::ID::Type id);
+    UMLWidget *widgetOnDiagram(WidgetBase::WidgetType type);
 
     bool isSavedInSeparateFile();
 
     void setMenu(const QPoint& pos);
 
     void resetToolbar();
+    void triggerToolbarButton(WorkToolBar::ToolBar_Buttons button);
 
     bool getPaste() const;
     void setPaste(bool paste);
@@ -223,7 +230,7 @@ public:
     void endPartialWidgetPaste();
     void beginPartialWidgetPaste();
 
-    void removeAssoc(AssociationWidget* pAssoc);
+    void removeWidgetCmd(AssociationWidget* pAssoc);
     void removeAssociations(UMLWidget* pWidget);
     void selectAssociations(bool bSelect);
 
@@ -276,7 +283,7 @@ public:
 
     // Load/Save interface:
 
-    virtual void saveToXMI1(QDomDocument & qDoc, QDomElement & qElement);
+    virtual void saveToXMI1(QXmlStreamWriter& writer);
     virtual bool loadFromXMI1(QDomElement & qElement);
 
     bool loadUISDiagram(QDomElement & qElement);
@@ -307,6 +314,20 @@ public:
 
     UMLSceneItemList collisions(const QPointF &p, int delta = 3);
 
+    bool isClassDiagram()              { return type() == Uml::DiagramType::Class;  }
+    bool isUseCaseDiagram()            { return type() == Uml::DiagramType::UseCase; }
+    bool isSequenceDiagram()           { return type() == Uml::DiagramType::Sequence; }
+    bool isCollaborationDiagram()      { return type() == Uml::DiagramType::Collaboration; }
+    bool isStateDiagram()              { return type() == Uml::DiagramType::State; }
+    bool isActivityDiagram()           { return type() == Uml::DiagramType::Activity; }
+    bool isComponentDiagram()          { return type() == Uml::DiagramType::Component; }
+    bool isDeploymentDiagram()         { return type() == Uml::DiagramType::Deployment; }
+    bool isEntityRelationshipDiagram() { return type() == Uml::DiagramType::EntityRelationship; }
+    bool isObjectDiagram()             { return type() == Uml::DiagramType::Object; }
+
+    void setWidgetLink(WidgetBase *w);
+    WidgetBase *widgetLink();
+
 protected:
     // Methods and members related to loading/saving
 
@@ -327,12 +348,6 @@ protected:
     QString          m_Documentation;  ///< The documentation of the diagram.
     Settings::OptionState  m_Options;  ///< Options used by view.
 
-    MessageWidgetList      m_MessageList;      ///< All the message widgets on the diagram.
-private:
-    UMLWidgetList          m_WidgetList;       ///< All the UMLWidgets on the diagram.
-protected:
-    AssociationWidgetList  m_AssociationList;  ///< All the AssociationWidgets on the diagram.
-
     bool m_bUseSnapToGrid;  ///< Flag to use snap to grid. The default is off.
     bool m_bUseSnapComponentSizeToGrid;  ///< Flag to use snap to grid for component size. The default is off.
     bool m_isOpen;  ///< Flag is set to true when diagram is open, i.e. shown to the user.
@@ -348,7 +363,7 @@ protected:
     void mousePressEvent(QGraphicsSceneMouseEvent* mouseEvent);
     void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* mouseEvent);
     void mouseReleaseEvent(QGraphicsSceneMouseEvent* mouseEvent);
-    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent* contextMenuEvent);
+    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent* event);
 
     QRectF diagramRect();
 
@@ -372,7 +387,7 @@ protected:
 #endif
 
     int m_nCollaborationId;  ///< Used for creating unique name of collaboration messages.
-    QPointF m_Pos;
+    QPointF m_pos;
     bool m_bCreateObject;
     bool m_bDrawSelectedOnly;
     bool m_bPaste;
@@ -386,8 +401,6 @@ private:
     UMLView *m_view;   ///< The view to which this scene is related.
     UMLFolder *m_pFolder;  ///< The folder in which this UMLView is contained.
 
-    ToolBarStateFactory* m_pToolBarStateFactory;
-    ToolBarState* m_pToolBarState;
     IDChangeLog * m_pIDChangesLog;  ///< LocalID Changes Log for paste actions
     bool m_isActivated;             ///< True if the view was activated after the serialization(load).
     bool m_bPopupShowing;           ///< Status of a popupmenu on view. True - a popup is on view.
@@ -435,6 +448,8 @@ signals:
     void sigShowGridToggled(bool);
     void sigAssociationRemoved(AssociationWidget*);
     void sigWidgetRemoved(UMLWidget*);
+
+    friend class DiagramProxyWidget;
 };
 
 QDebug operator<<(QDebug dbg, UMLScene *item);
