@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -46,7 +46,7 @@ class UMLOperation;
  * @author Gustavo Madrigal
  * @author Gopala Krishna
  * @short This class represents an association inside a diagram.
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class AssociationWidget : public WidgetBase, public LinkWidget
 {
@@ -144,7 +144,7 @@ public:
 
     AssociationLine* associationLine() const;
 
-    virtual bool activate();
+    virtual bool activate(IDChangeLog *changeLog = 0);
     virtual QRectF boundingRect() const;
     virtual QPainterPath shape() const;
 
@@ -183,7 +183,7 @@ public:
     bool loadFromXMI1(QDomElement& qElement, const UMLWidgetList& widgets,
                      const MessageWidgetList* messages);
     virtual bool loadFromXMI1(QDomElement& qElement);
-    virtual void saveToXMI1(QDomDocument &qDoc, QDomElement &qElement);
+    virtual void saveToXMI1(QXmlStreamWriter& writer);
 
     void cleanup();
 
